@@ -152,6 +152,8 @@ class Freestream(BaseModel):
 
     Reynolds: Optional[float] = Field()
     Mach: float = Field()
+    MachRef: Optional[float] = Field()
+    mu_ref: Optional[float] = Field(alias="muRef")
     Temperature: float
     alpha: float = Field(alias="alphaAngle", default=0)
     beta: float = Field(alias="betaAngle", default=0)
@@ -250,10 +252,6 @@ class Flow360MeshParams(BaseModel):
     boundaries: MeshBoundary = Field()
     sliding_interfaces: Optional[List[SlidingInterface]] = Field(alias="slidingInterfaces")
 
-    # pylint: disable=C0115,R0903
-    class Config:
-        allow_population_by_field_name = True
-
     def json(self, *args, **kwargs):
         """
         to json
@@ -266,3 +264,7 @@ class Flow360MeshParams(BaseModel):
         read model from json file
         """
         return cls.parse_file(file)
+
+    # pylint: disable=C0115,R0903
+    class Config:
+        allow_population_by_field_name = True
